@@ -43,10 +43,10 @@ object-oriented interface is one of the key capabilities of MDAnalysis.
 Readers
 -------
 
-All Readers are based on a :class:`ProtoReader` class that defines a common
-:ref:`Trajectory API` and allows other code to interface with all trajectory
-formats in the same way, independent of the details of the trajectory format
-itself.
+All Readers are based on a :class:`~MDAnalysis.coordinates.base.ProtoReader`
+class that defines a common :ref:`Trajectory API` and allows other code to
+interface with all trajectory formats in the same way, independent of the
+details of the trajectory format itself.
 
 The :class:`~MDAnalysis.core.universe.Universe` contains the API entry point
 attribute :attr:`Universe.trajectory` that points to the actual
@@ -123,13 +123,13 @@ Timesteps
 ---------
 
 Both Readers and Writers use Timesteps as their working object.  A
-:class:`~MDAnalysis.coordinates.base.Timestep` represents all data for a given
+:class:`~MDAnalysis.coordinates.Timestep` represents all data for a given
 frame in a trajectory.  The data inside a
-:class:`~MDAnalysis.coordinates.base.Timestep` is often accessed indirectly
+:class:`~MDAnalysis.coordinates.Timestep` is often accessed indirectly
 through a :class:`~MDAnalysis.core.groups.AtomGroup` but it is also possible to
 manipulate Timesteps directly.
 
-The current :class:`~MDAnalysis.coordinates.base.Timestep` can be accessed
+The current :class:`~MDAnalysis.coordinates.Timestep` can be accessed
 through the :attr:`~MDAnalysis.coordinates.base.ProtoReader.ts` attribute of
 the trajectory attached to the active
 :class:`~MDAnalysis.core.universe.Universe`::
@@ -328,7 +328,7 @@ A Timestep instance holds data for the current frame. It is updated whenever a
 new frame of the trajectory is read.
 
 Timestep classes are derived from
-:class:`MDAnalysis.coordinates.base.Timestep`, which is the primary
+:class:`MDAnalysis.coordinates.timestep.Timestep`, which is the primary
 implementation example (and used directly for the DCDReader).
 
 The discussion on this format is detailed in `Issue 250`_
@@ -429,7 +429,7 @@ but instead should use the attribute above.
   ``_unitcell``
       native unit cell description; the format depends on the
       underlying trajectory format. A user should use the
-      :class:`~MDAnalysis.coordinates.base.Timestep.dimensions`
+      :class:`~MDAnalysis.coordinates.Timestep.dimensions`
       attribute to access the data in a canonical format instead of
       accessing :class:`Timestep._unitcell` directly.
 
@@ -441,8 +441,22 @@ but instead should use the attribute above.
 Trajectory Reader class
 ~~~~~~~~~~~~~~~~~~~~~~~
 
-Trajectory readers are derived from :class:`MDAnalysis.coordinates.base.ReaderBase`.
-Typically, many methods and attributes are overriden.
+Trajectory readers are derived from
+:class:`MDAnalysis.coordinates.base.ReaderBase` (or from
+:class:`MDAnalysis.coordinates.base.ProtoReader` if they do not required
+:meth:`Reader.__del__` method). A special case are *SingleFrame readers* for
+formats that contain only a single coordinate frame. These readers are derived
+from a subclass of :class:`~MDAnalysis.coordinates.base.ProtoReader` named
+:class:`MDAnalysis.coordinates.base.SingleFrameReaderBase`.
+
+Typically, many methods and attributes are overriden but the ones listed below
+*must* be implemented.
+
+.. SeeAlso::
+
+   See the section on :ref:`ReadersBase` in :mod:`MDAnalysis.coordinates.base`
+   for implementation details.
+
 
 Methods
 .......
@@ -471,6 +485,13 @@ The following methods must be implemented in a Reader class.
         for ts in trajectory:
             print(ts.frame)
 
+     Readers will automatically rewind the trajectory to before the initial
+     frame (often by re-opening the file) before starting the iteration. *Multi
+     frame readers* (see :ref:`ReadersBase`) will also rewind the trajectory
+     *after* the iteration so that the current trajectory frame is set to the
+     first trajectory frame. *Single frame readers* do not explicitly rewind
+     after iteration but simply remain on the one frame in the trajectory.
+
  ``close()``
      close the file and cease I/O
  ``next()``
@@ -529,10 +550,11 @@ deal with missing methods gracefully.
      a trajectory.
 
      The performance of the ``__getitem__()`` method depends on the underlying
-     trajectory reader and if it can implement random access to frames. In many
-     cases this is not easily (or reliably) implementable and thus one is
-     restricted to sequential iteration.
+     trajectory reader and if it can implement random access to frames. All
+     readers in MDAnalysis should support random access.
 
+     For external custom readers this may not be easily (or reliably)
+     implementable and thus one is restricted to sequential iteration.
      If the Reader is not able to provide random access to frames then it
      should raise :exc:`TypeError` on indexing. It is possible to partially
      implement ``__getitem__`` (as done on
@@ -543,7 +565,7 @@ deal with missing methods gracefully.
 
      When indexed with a slice, a sequence of indices, or a mask of booleans,
      the return value is an instance of :class:`FrameIteratorSliced` or
-     :class:`FrameIteratorIndices`.
+     :class:`FrameIteratorIndices`. See :ref:`FrameIterators` for more details.
 
  ``parse_n_atoms(filename, **kwargs)``
      Provide the number of atoms in the trajectory file, allowing the Reader
@@ -574,8 +596,8 @@ Attributes
  ``n_frames``
      total number of frames (if known) -- ``None`` if not known
  ``ts``
-     the :class:`~base.Timestep` object; typically customized for each
-     trajectory format and derived from :class:`base.Timestep`.
+     the :class:`~timestep.Timestep` object; typically customized for each
+     trajectory format and derived from :class:`timestep.Timestep`.
  ``units``
      dictionary with keys *time*, *length*, *speed*, *force* and the
      appropriate unit (e.g. 'AKMA' and 'Angstrom' for Charmm dcds, 'ps' and
@@ -637,6 +659,10 @@ or::
 
    w.write(AtomGroup)  # write a selection of Atoms from Universe
 
+.. SeeAlso::
+
+   See the section on :ref:`WritersBase` in :mod:`MDAnalysis.coordinates.base`
+   for implementation details.
 
 Methods
 .......
@@ -717,12 +743,13 @@ Methods
 
    Trajectory and Frame writers can be used in almost exactly the same
    manner with the one difference that Frame writers cannot deal with
-   raw :class:`~MDAnalysis.coordinates.base.Timestep` objects.
+   raw :class:`~MDAnalysis.coordinates.Timestep` objects.
 
 """
-__all__ = ['reader', 'writer']
+__all__ = ['reader', 'writer', 'timestep']
 
 from . import base
+from . import timestep
 from .core import reader, writer
 from . import chain
 from . import chemfiles
