@@ -127,7 +127,7 @@ same functionality for any supported trajectory format::
   u = mda.Universe(PDB, XTC)
 
   coordinates = AnalysisFromFunction(lambda ag: ag.positions.copy(),
-                                     u.atoms).run().results
+                                     u.atoms).run().results['timeseries']
   u2 = mda.Universe(PDB, coordinates, format=MemoryReader)
 
 .. _creating-in-memory-trajectory-label:
@@ -154,7 +154,7 @@ only the protein is created::
   protein = u.select_atoms("protein")
 
   coordinates = AnalysisFromFunction(lambda ag: ag.positions.copy(),
-                                     protein).run().results
+                                     protein).run().results['timeseries']
   u2 = mda.Merge(protein)            # create the protein-only Universe
   u2.load_new(coordinates, format=MemoryReader)
 
@@ -164,7 +164,7 @@ principle, this could have all be done in one line::
 
   u2 = mda.Merge(protein).load_new(
            AnalysisFromFunction(lambda ag: ag.positions.copy(),
-                                protein).run().results,
+                                protein).run().results['timeseries'],
            format=MemoryReader)
 
 The new :class:`~MDAnalysis.core.universe.Universe` ``u2`` can be used
@@ -175,9 +175,6 @@ on the sub-system.
 Classes
 =======
 
-.. autoclass:: Timestep
-   :members:
-   :inherited-members:
 
 .. autoclass:: MemoryReader
    :members:
@@ -188,9 +185,10 @@ import logging
 import errno
 import numpy as np
 import warnings
+import copy
 
 from . import base
-from .base import Timestep
+from .timestep import Timestep
 
 
 # These methods all pass in an existing *view* onto a larger array
@@ -302,11 +300,15 @@ class MemoryReader(base.ProtoReader):
         .. versionchanged:: 0.19.0
             The input to the MemoryReader now must be a np.ndarray
             Added optional velocities and forces
+        .. versionchanged:: 2.2.0
+            Input kwargs are now stored under the :attr:`_kwargs` attribute,
+            and are passed on class creation in :meth:`copy`.
         """
 
         super(MemoryReader, self).__init__()
         self.filename = filename
         self.stored_order = order
+        self._kwargs = kwargs
 
         # See Issue #1685. The block below checks if the coordinate array
         # passed is of shape (N, 3) and if it is, the coordiante array is
@@ -444,6 +446,7 @@ class MemoryReader(base.ProtoReader):
             forces=fors,
             dt=self.ts.dt,
             filename=self.filename,
+            **self._kwargs
         )
         new[self.ts.frame]
 
