@@ -567,6 +567,28 @@ class SelgroupSelection(Selection):
         return group[mask]
 
 
+class SingleCharSelection(Selection):
+    """for when an attribute is just a single character, eg RSChirality
+
+    .. versionadded:: 2.1.0
+    """
+    def __init__(self, parser, tokens):
+        super().__init__(parser, tokens)
+        vals = grab_not_keywords(tokens)
+        if not vals:
+            raise ValueError("Unexpected token '{0}'".format(tokens[0]))
+
+        self.values = vals
+
+    @return_empty_on_apply
+    def _apply(self, group):
+        attr = getattr(group, self.field)
+
+        mask = np.isin(attr, self.values)
+
+        return group[mask]
+
+
 class _ProtoStringSelection(Selection):
     """Selections based on text attributes
 
@@ -615,6 +637,15 @@ class SmartsSelection(Selection):
 
     Uses RDKit to run the query and converts the result to MDAnalysis.
     Supports chirality.
+
+    .. versionchanged:: 2.2.0
+       ``rdkit_wargs`` and ``smarts_kwargs`` can now be passed to control
+       the behaviour of the RDKit converter and RDKit's ``GetSubstructMatches``
+       respectively.
+       The default ``maxMatches`` value passed to ``GetSubstructMatches`` has
+       been changed from ``1000`` to ``max(1000, n_atoms * 10)`` in order to
+       limit cases where too few matches were generated. A warning is now also
+       thrown if ``maxMatches`` has been reached.
     """
     token = 'smarts'
 
@@ -643,6 +674,7 @@ class SmartsSelection(Selection):
             pattern.append(val)
         self.pattern = "".join(pattern)
         self.rdkit_kwargs = parser.rdkit_kwargs
+        self.smarts_kwargs = parser.smarts_kwargs
 
     def _apply(self, group):
         try:
@@ -656,13 +688,22 @@ class SmartsSelection(Selection):
         if not pattern:
             raise ValueError(f"{self.pattern!r} is not a valid SMARTS query")
         mol = group.convert_to("RDKIT", **self.rdkit_kwargs)
-        matches = mol.GetSubstructMatches(pattern, useChirality=True)
-        # convert rdkit indices to mdanalysis'
-        indices = [
-            mol.GetAtomWithIdx(idx).GetIntProp("_MDAnalysis_index")
-            for match in matches for idx in match]
+        self.smarts_kwargs.setdefault("useChirality", True)
+        self.smarts_kwargs.setdefault("maxMatches", max(1000, len(group) * 10))
+        matches = mol.GetSubstructMatches(pattern, **self.smarts_kwargs)
+        if len(matches) == self.smarts_kwargs["maxMatches"]:
+            warnings.warn("Your smarts-based atom selection returned the max"
+                          "number of matches. This indicates that not all"
+                          "matching atoms were selected. When calling"
+                          "atom_group.select_atoms(), the default value"
+                          "of maxMatches is max(100, len(atom_group * 10)). "
+                          "To fix this, add the following argument to "
+                          "select_atoms: \n"
+                          "smarts_kwargs={maxMatches: <higher_value>}")
+        # flatten all matches and remove duplicated indices
+        indices = np.unique([idx for match in matches for idx in match])
         # create boolean mask for atoms based on index
-        mask = np.in1d(range(group.n_atoms), np.unique(indices))
+        mask = np.in1d(range(group.n_atoms), indices)
         return group[mask]
 
 
@@ -1388,7 +1429,7 @@ class SelectionParser(object):
                 "".format(self.tokens[0], token))
 
     def parse(self, selectstr, selgroups, periodic=None, atol=1e-08,
-              rtol=1e-05, sorted=True, rdkit_kwargs=None):
+              rtol=1e-05, sorted=True, rdkit_kwargs=None, smarts_kwargs=None):
         """Create a Selection object from a string.
 
         Parameters
@@ -1411,7 +1452,9 @@ class SelectionParser(object):
         rdkit_kwargs : dict, optional
             Arguments passed to the RDKitConverter when using selection based
             on SMARTS queries
-
+        smarts_kwargs : dict, optional
+          Arguments passed internally to RDKit's `GetSubstructMatches
+          <https://www.rdkit.org/docs/source/rdkit.Chem.rdchem.html#rdkit.Chem.rdchem.Mol.GetSubstructMatches>`_.
 
         Returns
         -------
@@ -1427,12 +1470,16 @@ class SelectionParser(object):
         .. versionchanged:: 2.0.0
             Added `atol` and `rtol` keywords to select float values. Added
             `rdkit_kwargs` to pass arguments to the RDKitConverter
+        .. versionchanged:: 2.2.0
+            Added ``smarts_kwargs`` argument, allowing users to pass a
+            a dictionary of arguments to RDKit's ``GetSubstructMatches``.
         """
         self.periodic = periodic
         self.atol = atol
         self.rtol = rtol
         self.sorted = sorted
         self.rdkit_kwargs = rdkit_kwargs or {}
+        self.smarts_kwargs = smarts_kwargs or {}
 
         self.selectstr = selectstr
         self.selgroups = selgroups
@@ -1550,7 +1597,9 @@ def gen_selection_class(singular, attrname, dtype, per_object):
                "__module__": _selectors.__name__}
     name = f"{singular.capitalize()}Selection"
 
-    if issubclass(dtype, bool):
+    if dtype == 'U1':  # order is important here, U1 will trip up issubclass
+        basecls = SingleCharSelection
+    elif issubclass(dtype, bool):
         basecls = BoolSelection
     elif np.issubdtype(dtype, np.integer):
         basecls = RangeSelection
