@@ -152,6 +152,7 @@ Class decorators
 ----------------
 
 .. autofunction:: cached
+.. autofunction:: store_init_arguments
 
 Function decorators
 -------------------
@@ -213,6 +214,7 @@ import inspect
 from .picklable_file_io import pickle_open, bz2_pickle_open, gzip_pickle_open
 
 from ..exceptions import StreamWarning, DuplicateWarning
+
 try:
     from ._cutil import unique_int_1d
 except ImportError:
@@ -725,6 +727,9 @@ class NamedStream(io.IOBase, os.PathLike):
                   always closes the underlying stream.
 
         """
+        if self.closed:
+            return
+
         if self.close_stream or force:
             try:
                 return self.stream.close()
@@ -1933,12 +1938,17 @@ def check_coords(*coord_names, **options):
     :mod:`MDAnalysis.lib.distances`.
     It takes an arbitrary number of positional arguments which must correspond
     to names of positional arguments of the decorated function.
-    It then checks if the corresponding values are valid coordinate arrays.
-    If all these arrays are single coordinates (i.e., their shape is ``(3,)``),
-    the decorated function can optionally return a single coordinate (or angle)
-    instead of an array of coordinates (or angles). This can be used to enable
-    computations of single observables using functions originally designed to
-    accept only 2-d coordinate arrays.
+    It then checks if the corresponding values are valid coordinate arrays or
+    an :class:`~MDAnalysis.core.groups.AtomGroup`.
+    If the input is an array and all these arrays are single coordinates
+    (i.e., their shape is ``(3,)``), the decorated function can optionally
+    return a single coordinate (or angle) instead of an array of coordinates
+    (or angles). This can be used to enable computations of single observables
+    using functions originally designed to accept only 2-d coordinate arrays.
+
+    If the input is an :class:`~MDAnalysis.core.groups.AtomGroup` it is
+    converted into its corresponding position array via a call to
+    `AtomGroup.positions`.
 
     The checks performed on each individual coordinate array are:
 
@@ -1961,6 +1971,8 @@ def check_coords(*coord_names, **options):
         * **enforce_copy** (:class:`bool`, optional) -- Enforce working on a
           copy of the coordinate arrays. This is useful to ensure that the input
           arrays are left unchanged. Default: ``True``
+        * **enforce_dtype** (:class:`bool`, optional) -- Enforce a conversion
+          to float32.  Default: ``True``
         * **allow_single** (:class:`bool`, optional) -- Allow the input
           coordinate array to be a single coordinate with shape ``(3,)``.
         * **convert_single** (:class:`bool`, optional) -- If ``True``, single
@@ -1973,6 +1985,9 @@ def check_coords(*coord_names, **options):
         * **check_lengths_match** (:class:`bool`, optional) -- If ``True``, a
           :class:`ValueError` is raised if not all coordinate arrays contain the
           same number of coordinates. Default: ``True``
+        * **allow_atomgroup** (:class:`bool`, optional) -- If ``False``, a
+          :class:`TypeError` is raised if an :class:`AtomGroup` is supplied
+          Default: ``False``
 
     Raises
     ------
@@ -1986,7 +2001,8 @@ def check_coords(*coord_names, **options):
 
         If any of the coordinate arrays has a wrong shape.
     TypeError
-        If any of the coordinate arrays is not a :class:`numpy.ndarray`.
+        If any of the coordinate arrays is not a :class:`numpy.ndarray` or an
+        :class:`~MDAnalysis.core.groups.AtomGroup`.
 
         If the dtype of any of the coordinate arrays is not convertible to
           ``numpy.float32``.
@@ -1994,7 +2010,7 @@ def check_coords(*coord_names, **options):
     Example
     -------
 
-    >>> @check_coords('coords1', 'coords2')
+    >>> @check_coords('coords1', 'coords2', allow_atomgroup=True)
     ... def coordsum(coords1, coords2):
     ...     assert coords1.dtype == np.float32
     ...     assert coords2.flags['C_CONTIGUOUS']
@@ -2008,19 +2024,29 @@ def check_coords(*coord_names, **options):
     >>> coordsum(np.zeros(3), np.ones(6)[::2])
     array([1., 1., 1.], dtype=float32)
     >>>
+    >>> # automatic handling of AtomGroups
+    >>> u = mda.Universe(PSF, DCD)
+    >>> coordsum(u.atoms, u.select_atoms("index 1 to 10"))
+    ...
+    >>>
     >>> # automatic shape checking:
     >>> coordsum(np.zeros(3), np.ones(6))
     ValueError: coordsum(): coords2.shape must be (3,) or (n, 3), got (6,).
 
 
     .. versionadded:: 0.19.0
+    .. versionchanged:: 2.3.0
+       Can now accept an :class:`AtomGroup` as input, and added option
+       allow_atomgroup with default False to retain old behaviour
     """
     enforce_copy = options.get('enforce_copy', True)
+    enforce_dtype = options.get('enforce_dtype', True)
     allow_single = options.get('allow_single', True)
     convert_single = options.get('convert_single', True)
     reduce_result_if_single = options.get('reduce_result_if_single', True)
     check_lengths_match = options.get('check_lengths_match',
                                       len(coord_names) > 1)
+    allow_atomgroup = options.get('allow_atomgroup', False)
     if not coord_names:
         raise ValueError("Decorator check_coords() cannot be used without "
                          "positional arguments.")
@@ -2044,31 +2070,49 @@ def check_coords(*coord_names, **options):
                                  "".format(name, func.__name__))
 
         def _check_coords(coords, argname):
-            if not isinstance(coords, np.ndarray):
-                raise TypeError("{}(): Parameter '{}' must be a numpy.ndarray, "
-                                "got {}.".format(fname, argname, type(coords)))
             is_single = False
-            if allow_single:
-                if (coords.ndim not in (1, 2)) or (coords.shape[-1] != 3):
-                    raise ValueError("{}(): {}.shape must be (3,) or (n, 3), "
-                                     "got {}.".format(fname, argname,
-                                                      coords.shape))
-                if coords.ndim == 1:
-                    is_single = True
-                    if convert_single:
-                        coords = coords[None, :]
+            if isinstance(coords, np.ndarray):
+                if allow_single:
+                    if (coords.ndim not in (1, 2)) or (coords.shape[-1] != 3):
+                        errmsg = (f"{fname}(): {argname}.shape must be (3,) or "
+                                  f"(n, 3), got {coords.shape}")
+                        raise ValueError(errmsg)
+                    if coords.ndim == 1:
+                        is_single = True
+                        if convert_single:
+                            coords = coords[None, :]
+                else:
+                    if (coords.ndim != 2) or (coords.shape[1] != 3):
+                        errmsg = (f"{fname}(): {argname}.shape must be (n, 3) "
+                                  f"got {coords.shape}")
+                        raise ValueError(errmsg)
+                if enforce_dtype:
+                    try:
+                        coords = coords.astype(
+                            np.float32, order='C', copy=enforce_copy)
+                    except ValueError:
+                        errmsg = (f"{fname}(): {argname}.dtype must be"
+                                  f"convertible to float32, got"
+                                  f" {coords.dtype}.")
+                        raise TypeError(errmsg) from None
+                # coordinates should now be the right shape
+                ncoord = coords.shape[0]
             else:
-                if (coords.ndim != 2) or (coords.shape[1] != 3):
-                    raise ValueError("{}(): {}.shape must be (n, 3), got {}."
-                                     "".format(fname, argname, coords.shape))
-            try:
-                coords = coords.astype(
-                    np.float32, order='C', copy=enforce_copy)
-            except ValueError:
-                errmsg = (f"{fname}(): {argname}.dtype must be convertible to "
-                          f"float32, got {coords.dtype}.")
-                raise TypeError(errmsg) from None
-            return coords, is_single
+                try:
+                    coords = coords.positions  # homogenise to a numpy array
+                    ncoord = coords.shape[0]
+                    if not allow_atomgroup:
+                        err = TypeError("AtomGroup or other class with a"
+                                        "`.positions` method supplied as an"
+                                        "argument, but allow_atomgroup is"
+                                        " False")
+                        raise err
+                except AttributeError:
+                    raise TypeError(f"{fname}(): Parameter '{argname}' must be"
+                                    f" a numpy.ndarray or an AtomGroup,"
+                                    f" got {type(coords)}.")
+
+            return coords, is_single, ncoord
 
         @wraps(func)
         def wrapper(*args, **kwargs):
@@ -2099,14 +2143,15 @@ def check_coords(*coord_names, **options):
             for name in coord_names:
                 idx = posargnames.index(name)
                 if idx < len(args):
-                    args[idx], is_single = _check_coords(args[idx], name)
+                    args[idx], is_single, ncoord = _check_coords(args[idx],
+                                                                 name)
                     all_single &= is_single
-                    ncoords.append(args[idx].shape[0])
+                    ncoords.append(ncoord)
                 else:
-                    kwargs[name], is_single = _check_coords(kwargs[name],
-                                                            name)
+                    kwargs[name], is_single, ncoord = _check_coords(kwargs[name],
+                                                                    name)
                     all_single &= is_single
-                    ncoords.append(kwargs[name].shape[0])
+                    ncoords.append(ncoord)
             if check_lengths_match and ncoords:
                 if ncoords.count(ncoords[0]) != len(ncoords):
                     raise ValueError("{}(): {} must contain the same number of "
@@ -2365,7 +2410,7 @@ def check_box(box):
     box : array_like
         The unitcell dimensions of the system, which can be orthogonal or
         triclinic and must be provided in the same format as returned by
-        :attr:`MDAnalysis.coordinates.base.Timestep.dimensions`:
+        :attr:`MDAnalysis.coordinates.timestep.Timestep.dimensions`:
         ``[lx, ly, lz, alpha, beta, gamma]``.
 
     Returns
@@ -2410,3 +2455,42 @@ def check_box(box):
     if np.all(box[3:] == 90.):
         return 'ortho', box[:3]
     return 'tri_vecs', triclinic_vectors(box)
+
+
+def store_init_arguments(func):
+    """Decorator to store arguments passed to the init method of a class.
+
+    Arguments are stored as a dictionary in ``cls._kwargs``.
+
+    Notes
+    -----
+    * Only does a shallow copy, if the arguments are changed
+      by the class after passing through the decorator this will be
+      reflected in the stored arguments.
+    * If not empty, ``args`` is not unpacked and stored as-is in the
+      dictionary. If no ``args`` are passed, then no ``arg`` entry will be
+      stored in the dictionary.
+
+
+    .. versionadded:: 2.2.0
+    """
+    sig = inspect.signature(func)
+
+    @functools.wraps(func)
+    def wrapper(self, *args, **kwargs):
+        if not hasattr(self, "_kwargs"):
+            arg_values = sig.bind(self, *args, **kwargs)
+            arg_values.apply_defaults()
+            self._kwargs = {}
+            for key, arg in arg_values.arguments.items():
+                if key != "self":
+                    if key == "kwargs":
+                        for k, v in arg.items():
+                            self._kwargs[k] = v
+                    elif key == "args":
+                        if len(arg) > 0:
+                            self._kwargs[key] = arg
+                    else:
+                        self._kwargs[key] = arg
+        return func(self, *args, **kwargs)
+    return wrapper
