@@ -552,3 +552,34 @@ class TestHydrogenBondAnalysisTIP3PStartStep(object):
 
         counts = h.count_by_type()
         assert int(counts[0, 2]) == ref_count
+
+
+class TestHydrogenBondAnalysisEmptySelections:
+
+    @staticmethod
+    @pytest.fixture(scope='class')
+    def universe():
+        return MDAnalysis.Universe(waterPSF, waterDCD)
+
+    msg = ("{} is an empty selection string - no hydrogen bonds will "
+           "be found. This may be intended, but please check your "
+           "selection."
+           )
+
+    @pytest.mark.parametrize('seltype',
+            ['donors_sel', 'hydrogens_sel', 'acceptors_sel'])
+    def test_empty_sel(self, universe, seltype):
+        sel_kwarg = {seltype: ' '}
+        with pytest.warns(UserWarning, match=self.msg.format(seltype)):
+            HydrogenBondAnalysis(universe, **sel_kwarg)
+
+    def test_hbond_analysis(self, universe):
+
+        h = HydrogenBondAnalysis(universe, donors_sel=' ', hydrogens_sel=' ',
+                                 acceptors_sel=' ')
+        h.run()
+
+        assert h.donors_sel == ''
+        assert h.hydrogens_sel == ''
+        assert h.acceptors_sel == ''
+        assert h.results.hbonds.size == 0
