@@ -1,7 +1,8 @@
 import pytest
-from numpy.testing import assert_almost_equal, assert_equal
+from numpy.testing import assert_almost_equal, assert_equal, assert_allclose
 import numpy as np
 import sys
+import os
 import MDAnalysis as mda
 from MDAnalysis.coordinates.H5MD import HAS_H5PY
 if HAS_H5PY:
@@ -75,6 +76,39 @@ class TestH5MDReaderBaseAPI(MultiframeReaderTest):
                 assert_equal(isinstance(W, ref.writer), True)
                 assert_equal(W.n_atoms, 100)
 
+    def test_copying(self, ref, reader):
+        # Issue #3664 - test not done in test_copying due to dependencies
+        original = mda.coordinates.H5MD.H5MDReader(
+                ref.trajectory, convert_units=False, dt=2,
+                time_offset=10, foo="bar")
+        copy = original.copy()
+
+        assert original.format not in ('MEMORY', 'CHAIN')
+        assert original.convert_units is False
+        assert copy.convert_units is False
+        assert original._ts_kwargs['time_offset'] == 10
+        assert copy._ts_kwargs['time_offset'] == 10
+        assert original._ts_kwargs['dt'] == 2
+        assert copy._ts_kwargs['dt'] == 2
+
+        assert original.ts.data['time_offset'] == 10
+        assert copy.ts.data['time_offset'] == 10
+
+        assert original.ts.data['dt'] == 2
+        assert copy.ts.data['dt'] == 2
+
+        assert copy._kwargs['foo'] == 'bar'
+
+        # check coordinates
+        assert original.ts.frame == copy.ts.frame
+        assert_allclose(original.ts.positions, copy.ts.positions)
+
+        original.next()
+        copy.next()
+
+        assert original.ts.frame == copy.ts.frame
+        assert_allclose(original.ts.positions, copy.ts.positions)
+
 
 @pytest.mark.skipif(not HAS_H5PY, reason="h5py not installed")
 class TestH5MDWriterBaseAPI(BaseWriterTest):
@@ -380,6 +414,42 @@ class TestH5MDReaderWithRealTrajectory(object):
         u = mda.Universe(TPR_xvf, H5MD_xvf, driver="core")
         assert_equal(u.trajectory._file.driver, "core")
 
+    @pytest.mark.parametrize('group1, group2', (('velocity', 'force'),
+                                                ('position', 'force'),
+                                                ('position', 'velocity')))
+    def test_parse_n_atoms(self, h5md_file, outfile, group1, group2):
+        with h5md_file as f:
+            with h5py.File(outfile, 'w') as g:
+                f.copy(source='particles', dest=g)
+                f.copy(source='h5md', dest=g)
+                traj_group = g['particles/trajectory']
+                del traj_group[group1]
+                del traj_group[group2]
+                for dset in ('position/value', 'velocity/value',
+                             'force/value'):
+                    try:
+                        n_atoms_in_dset = traj_group[dset].shape[1]
+                        break
+                    except KeyError:
+                        continue
+
+        u = mda.Universe(outfile)
+        assert_equal(u.atoms.n_atoms, n_atoms_in_dset)
+
+    def test_parse_n_atoms_error(self, h5md_file, outfile):
+        with h5md_file as f:
+            with h5py.File(outfile, 'w') as g:
+                f.copy(source='particles', dest=g)
+                f.copy(source='h5md', dest=g)
+                traj_group = g['particles/trajectory']
+                del traj_group['position']
+                del traj_group['velocity']
+                del traj_group['force']
+
+        errmsg = "Could not construct minimal topology"
+        with pytest.raises(ValueError, match=errmsg):
+            u = mda.Universe(outfile)
+
 
 @pytest.mark.skipif(not HAS_H5PY, reason="h5py not installed")
 class TestH5MDWriterWithRealTrajectory(object):
@@ -744,6 +814,8 @@ class TestH5MDWriterWithRealTrajectory(object):
         assert_equal(dset.compression, filter)
         assert_equal(dset.compression_opts, opts)
 
+    @pytest.mark.xfail(os.name == 'nt',
+                       reason="occasional PermissionError on windows")
     @pytest.mark.parametrize('driver', ('core', 'stdio'))
     def test_write_with_drivers(self, universe, outfile, Writer, driver):
         with Writer(outfile,
