@@ -29,15 +29,15 @@ import pytest
 import MDAnalysis as mda
 from MDAnalysis import NoDataError
 
-from numpy.testing import (assert_equal, assert_almost_equal)
+from numpy.testing import (assert_equal, assert_almost_equal, assert_allclose)
 
 from MDAnalysisTests import make_Universe
 from MDAnalysisTests.coordinates.reference import (
     RefLAMMPSData, RefLAMMPSDataMini, RefLAMMPSDataDCD,
 )
 from MDAnalysisTests.datafiles import (
-    LAMMPScnt, LAMMPShyd, LAMMPSdata, LAMMPSdata_mini, LAMMPSDUMP,
-    LAMMPSDUMP_allcoords, LAMMPSDUMP_nocoords
+    LAMMPScnt, LAMMPShyd, LAMMPSdata, LAMMPSdata_mini, LAMMPSdata_triclinic,
+    LAMMPSDUMP, LAMMPSDUMP_allcoords, LAMMPSDUMP_nocoords, LAMMPSDUMP_triclinic
 )
 
 
@@ -625,3 +625,46 @@ class TestCoordinateMatches(object):
         for ts_a, ts_s in zip(universes["auto"].trajectory,
                               universes["unscaled"].trajectory):
             assert_almost_equal(ts_a.positions, ts_s.positions, decimal=5)
+
+
+class TestLammpsTriclinic(object):
+    @pytest.fixture()
+    def u_dump(self):
+        return mda.Universe(LAMMPSDUMP_triclinic, format='LAMMPSDUMP',
+                            lammps_coordinate_convention="auto")
+
+    @pytest.fixture()
+    def u_data(self):
+        return mda.Universe(LAMMPSdata_triclinic, format='data',
+                            atom_style='id type x y z')
+
+    @pytest.fixture()
+    def reference_box(self):
+        # manually copied from triclinic data file
+        xlo = -0.32115478301032807
+        xhi = 16.831069399898624
+        ylo = -0.12372358703610897
+        yhi = 25.95896427399614
+        zlo = -0.045447071698045266
+        zhi = 12.993982724334792
+        xy = 1.506743915478767
+        xz = -6.266414551929444
+        yz = -0.42179319547892025
+
+        box = np.zeros((3, 3), dtype=np.float64)
+        box[0] = xhi - xlo, 0.0, 0.0
+        box[1] = xy, yhi - ylo, 0.0
+        box[2] = xz, yz, zhi - zlo
+
+        return mda.lib.mdamath.triclinic_box(*box)
+
+    def test_box(self, u_dump, u_data, reference_box):
+        # NOTE threefold validation testing both data and dump reader.
+        for ts in u_dump.trajectory:
+            assert_allclose(ts.dimensions, reference_box, rtol=1e-5, atol=0)
+
+        for ts in u_dump.trajectory:
+            assert_allclose(ts.dimensions, u_data.dimensions,
+                            rtol=1e-5, atol=0)
+
+        assert_allclose(u_data.dimensions, reference_box, rtol=1e-5, atol=0)
